@@ -2,7 +2,7 @@
 #define POLLARDRHO_GMP_R
 
 #include <Rcpp.h>
-#include <gmp.h>
+#include "GmpxxCopy.h"
 #include "Primes.h"
 
 /**
@@ -12,11 +12,10 @@
  *
  * Note: this is adapted from demo "factorize.c" file from gmplib
  */
-void GetPrimeFactors(mpz_t t, mpz_t *const factors, std::size_t &numPs,
+void GetPrimeFactors(mpz_class &t, std::vector<mpz_class> &factors,
                      std::vector<std::size_t> &myLens);
 
-int TrialDivision(mpz_t t, mpz_t *const factors, std::size_t& numPs,
-                  std::vector<std::size_t>& myLens, 
-                  std::size_t arrayMax);
+void TrialDivision(mpz_class &t, std::vector<mpz_class> &factors,
+                   std::vector<std::size_t> &myLens);
 
 #endif
